@@ -1,6 +1,6 @@
 
 ##
-require("slam", lib.loc = "../../slam.Rcheck")
+require("slam")
 
 ##
 x <- matrix(c(1L, 0L, 3L, 0L, 5L, 0L), ncol = 2,
